@@ -114,7 +114,9 @@ def bool_chks(window,opened_dict):
     bool_dict_params_EOS = {stri:window['--Chk_calc_params_'+stri].get() for stri in opened_dict.keys()}
     bool_dict_EOS =  {stri:opened_dict[stri] for stri in opened_dict.keys()}
     bool_run_eos_fitting = any([all([True,bool_dict_EOS[stri]]) for stri in opened_dict.keys()])
-    bool_mode = any([window['--Chk_mode_'+stri].get() for stri in ['jjsl', 'jjdm', 'jjfv', 'DM', 'Sl', 'VZ', 'mfv']])
+    bool_mode = any([window['--Chk_mode_'+stri].get() for stri in ['jjsl', 'jjdm', 'jjfv',
+                                                                   # 'DM', 'Sl', 'VZ', 'mfv'
+                                                                   ]])
 
 
     return bool_run_eos_fitting, bool_dict_params_EOS, bool_mode
